@@ -12,13 +12,13 @@ from typing import Union, Callable
 import time
 
 import epde.globals as global_var
-from epde.interface.token_family import Token_family
-from epde.evaluators import Custom_Evaluator, Evaluator_template, trigonometric_evaluator, simple_function_evaluator 
+from epde.interface.token_family import TokenFamily
+from epde.evaluators import CustomEvaluator, EvaluatorTemplate, trigonometric_evaluator, simple_function_evaluator 
 from epde.cache.cache import upload_simple_tokens, np_ndarray_section
 
 class Prepared_tokens(ABC):
     def __init__(self, *args, **kwargs):
-        self._token_family = Token_family(token_type = 'Placeholder')
+        self._token_family = TokenFamily(token_type = 'Placeholder')
         
     @property
     def token_family(self):
@@ -31,7 +31,7 @@ class Trigonometric_tokens(Prepared_tokens):
     def __init__(self, freq : tuple = (np.pi/2., 2*np.pi), dimensionality = 1):
         assert freq[1] > freq[0] and len(freq) == 2, 'The tuple, defining frequncy interval, shall contain 2 elements with first - the left boundary of interval and the second - the right one. '
 
-        self._token_family = Token_family(token_type='trigonometric')
+        self._token_family = TokenFamily(token_type='trigonometric')
         self._token_family.set_status(unique_specific_token=True, unique_token_type=True, 
                            meaningful = False, unique_for_right_part = False)
         
@@ -51,27 +51,27 @@ class Logfun_tokens(Prepared_tokens):
         
 class Custom_tokens(Prepared_tokens):
     def __init__(self, token_type : str, token_labels : list, 
-                 evaluator : Union[Custom_Evaluator, Evaluator_template, Callable], 
+                 evaluator : Union[CustomEvaluator, EvaluatorTemplate, Callable], 
                  params_ranges : dict, params_equality_ranges : Union[None, dict], dimensionality : int = 1,
                  unique_specific_token=True, unique_token_type=True, meaningful = False, 
                  unique_for_right_part = False):
-        self._token_family = Token_family(token_type = token_type)
+        self._token_family = TokenFamily(token_type = token_type)
         self._token_family.set_status(unique_specific_token = unique_specific_token, 
                                       unique_token_type = unique_token_type, meaningful = meaningful, 
                                       unique_for_right_part = unique_for_right_part)
-        undeclared_param_eq_fraction = 0.5
+        default_param_eq_fraction = 0.5
         if params_equality_ranges is not None:
             for param_key, interval in params_ranges.items():
                 if param_key not in params_equality_ranges.keys():
                     if isinstance(interval[0], float):
-                        params_equality_ranges[param_key] = (interval[1] - interval[0]) * undeclared_param_eq_fraction
+                        params_equality_ranges[param_key] = (interval[1] - interval[0]) * default_param_eq_fraction
                     elif isinstance(interval[0], int):
                         params_equality_ranges[param_key] = 0
         else:
             params_equality_ranges = dict()
             for param_key, interval in params_ranges.items():
                 if isinstance(interval[0], float):
-                    params_equality_ranges[param_key] = (interval[1] - interval[0]) * undeclared_param_eq_fraction
+                    params_equality_ranges[param_key] = (interval[1] - interval[0]) * default_param_eq_fraction
                 elif isinstance(interval[0], int):
                     params_equality_ranges[param_key] = 0
 
@@ -85,15 +85,12 @@ class Cache_stored_tokens(Custom_tokens):
                  unique_specific_token=True, unique_token_type=True, meaningful = False, 
                  unique_for_right_part = False):
         if set(token_labels) != set(list(token_tensors.keys())):
-#            print(set(token_labels), set(token_tensors.keys()))
             raise KeyError('The labels of tokens do not match the labels of passed tensors')
         for key, val in token_tensors.items():
             token_tensors[key] = np_ndarray_section(val, boundary = boundary)
         upload_simple_tokens(list(token_tensors.keys()), global_var.tensor_cache, list(token_tensors.values()))
-#        print(f'Loaded {token_tensors.keys()} into the cache. The cache contains {global_var.tensor_cache.memory_default.keys()}')
-#        time.sleep(10)
         super().__init__(token_type = token_type, token_labels = token_labels, evaluator = simple_function_evaluator, 
                          params_ranges = params_ranges, params_equality_ranges = params_equality_ranges, 
                          dimensionality = dimensionality, unique_specific_token = unique_specific_token, 
                          unique_token_type = unique_token_type, meaningful = meaningful, 
-                         unique_for_right_part = unique_for_right_part)
\ No newline at end of file
+                         unique_for_right_part = unique_for_right_part)
